@@ -8,7 +8,7 @@ package Device::Chip;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
@@ -112,9 +112,19 @@ sub mount
    my $self = shift;
    ( $self->{adapter} ) = @_;
 
-   $self->{adapter}->make_protocol( $self->PROTOCOL )
-      ->on_done( sub { ( $self->{protocol} ) = @_ } )
-      ->then_done( $self );
+   my $pname = $self->PROTOCOL;
+
+   $self->{adapter}->make_protocol( $pname )
+      ->then( sub {
+         ( $self->{protocol} ) = @_;
+
+         my $code = $self->can( "${pname}_options" ) or
+            return Future->done( $self );
+
+         $self->protocol->configure(
+            $self->$code()
+         )->then_done( $self );
+      });
 }
 
 =head1 AUTHOR
